﻿Public Class Form1
    ' The data source.
    Private m_ContactsTable As DataTable

    ' The data source's CurrencyManager.
    Private WithEvents m_CurrencyManager As CurrencyManager

    Private Sub Form1_Load() Handles MyBase.Load
        ' Make a DataTable.
        m_ContactsTable = New DataTable("Contacts")

        ' Add columns.
        m_ContactsTable.Columns.Add("FirstName", GetType(String))
        m_ContactsTable.Columns.Add("LastName", GetType(String))
        m_ContactsTable.Columns.Add("Street", GetType(String))
        m_ContactsTable.Columns.Add("City", GetType(String))
        m_ContactsTable.Columns.Add("State", GetType(String))
        m_ContactsTable.Columns.Add("Zip", GetType(String))

        ' Make the combined FirstName/LastName unique.
        Dim first_last_columns() As DataColumn = {
            m_ContactsTable.Columns("FirstName"),
            m_ContactsTable.Columns("LastName")
        }
        m_ContactsTable.Constraints.Add(
            New UniqueConstraint(first_last_columns))

        ' Make some contact data.
        m_ContactsTable.Rows.Add(New Object() {"Art", "Ant",
            "1234 Ash Pl", "Bugville", "CO", "11111"})
        m_ContactsTable.Rows.Add(New Object() {"Bev", "Bug",
            "22 Beach St", "Bugville", "CO", "22222"})
        m_ContactsTable.Rows.Add(New Object() {"Cid", "Cat",
            "3 Road Place Lane", "Programmeria", "KS", "33333"})
        m_ContactsTable.Rows.Add(New Object() {"Deb", "Dove",
            "414 Debugger Way", "Programmeria", "KS", "44444"})
        m_ContactsTable.Rows.Add(New Object() {"Ed", "Eager",
            "5746 Elm Blvd", "Bugville", "CO", "55555"})
        m_ContactsTable.Rows.Add(New Object() {"Fran", "Fix",
            "647 Foxglove Ct", "Bugville", "CO", "66666"})
        m_ContactsTable.Rows.Add(New Object() {"Gus", "Gantry",
            "71762-B Gooseberry Ave", "Programmeria", "KS", "77777"})
        m_ContactsTable.Rows.Add(New Object() {"Hil", "Harris",
            "828 Hurryup St", "Programmeria", "KS", "88888"})

        ' Bind to controls.
        txtFirstName.DataBindings.Add("Text", m_ContactsTable, "FirstName")
        txtLastName.DataBindings.Add("Text", m_ContactsTable, "LastName")
        txtStreet.DataBindings.Add("Text", m_ContactsTable, "Street")
        txtCity.DataBindings.Add("Text", m_ContactsTable, "City")
        txtState.DataBindings.Add("Text", m_ContactsTable, "State")
        txtZip.DataBindings.Add("Text", m_ContactsTable, "Zip")

        ' Save a reference to the CurrencyManager.
        m_CurrencyManager =
            DirectCast(Me.BindingContext(m_ContactsTable), CurrencyManager)

        ' Display the first record's position.
        m_CurrencyManager_PositionChanged()
    End Sub

    Private Sub btnFirst_Click() Handles btnFirst.Click
        m_CurrencyManager.Position = 0
    End Sub

    Private Sub btnPrev_Click() Handles btnPrev.Click
        m_CurrencyManager.Position -= 1
    End Sub

    Private Sub btnNext_Click() Handles btnNext.Click
        m_CurrencyManager.Position += 1
    End Sub

    Private Sub btnLast_Click() Handles btnLast.Click
        m_CurrencyManager.Position = m_CurrencyManager.Count - 1
    End Sub

    ' Add a new record.
    Private Sub btnAdd_Click() Handles btnAdd.Click
        m_CurrencyManager.AddNew()
    End Sub

    ' Delete the current record.
    Private Sub btnDelete_Click() Handles btnDelete.Click
        If MsgBox("Are you sure you want to delete this record?",
            MsgBoxStyle.Question Or MsgBoxStyle.YesNo,
            "Confirm Delete?") = MsgBoxResult.Yes _
        Then
            m_CurrencyManager.RemoveAt(m_CurrencyManager.Position)
            m_CurrencyManager_PositionChanged()
        End If
    End Sub

    ' Display the CurrencyManager's current position.
    Private Sub m_CurrencyManager_PositionChanged() Handles m_CurrencyManager.PositionChanged
        lblPosition.Text =
            "Record " &
            m_CurrencyManager.Position + 1 &
            " of " &
            m_CurrencyManager.Count
    End Sub
End Class
